@@ -1,8 +1,8 @@
 /* BEGIN_COMMON_COPYRIGHT_HEADER
  * (c)LGPL2+
  *
- * LXDE-Qt - a lightweight, Qt based, desktop toolset
- * http://razor-qt.org
+ * LXQt - a lightweight, Qt based, desktop toolset
+ * https://lxqt.org
  *
  * Copyright: 2012 Razor team
  * Authors:
@@ -29,7 +29,7 @@
 
 #include <LXQt/ConfigDialog>
 
-class MainWindow : public LxQt::ConfigDialog
+class MainWindow : public LXQt::ConfigDialog
 {
     Q_OBJECT
 
