@@ -9,75 +9,96 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../batterywatchersettings.ui" line="37"/>
+        <location filename="../batterywatchersettings.ui" line="26"/>
         <source>E&amp;nable Battery Watcher</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../batterywatchersettings.ui" line="55"/>
+        <location filename="../batterywatchersettings.ui" line="54"/>
         <source>Warning:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../batterywatchersettings.ui" line="68"/>
+        <location filename="../batterywatchersettings.ui" line="67"/>
         <source> seconds</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../batterywatchersettings.ui" line="78"/>
+        <location filename="../batterywatchersettings.ui" line="77"/>
         <source>Level is low at:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../batterywatchersettings.ui" line="91"/>
+        <location filename="../batterywatchersettings.ui" line="90"/>
         <source> %</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../batterywatchersettings.ui" line="98"/>
+        <location filename="../batterywatchersettings.ui" line="111"/>
         <source>Use icons from theme:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../batterywatchersettings.ui" line="112"/>
+        <location filename="../batterywatchersettings.ui" line="125"/>
+        <location filename="../batterywatchersettings.cpp" line="93"/>
+        <source>Preview</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../batterywatchersettings.ui" line="162"/>
+        <source>Charging</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../batterywatchersettings.ui" line="200"/>
+        <source>Discharging</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../batterywatchersettings.ui" line="41"/>
         <source>When power is low then:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../batterywatchersettings.ui" line="129"/>
+        <location filename="../batterywatchersettings.ui" line="97"/>
         <source>Show icon:</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../batterywatchersettings.cpp" line="93"/>
+        <source>built in</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../batterywatchersettings.cpp" line="98"/>
+        <source>Level: %1%</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>IdlenessWatcherSettings</name>
     <message>
-        <location filename="../idlenesswatchersettings.ui" line="14"/>
-        <source>Form</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../idlenesswatchersettings.ui" line="26"/>
+        <location filename="../idlenesswatchersettings.ui" line="17"/>
         <source>Enab&amp;le Idleness Watcher</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../idlenesswatchersettings.ui" line="47"/>
+        <location filename="../idlenesswatchersettings.ui" line="38"/>
         <source>When idle then:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../idlenesswatchersettings.ui" line="66"/>
+        <location filename="../idlenesswatchersettings.ui" line="57"/>
         <source>Idle time:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../idlenesswatchersettings.ui" line="79"/>
+        <location filename="../idlenesswatchersettings.ui" line="70"/>
         <source> minutes</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../idlenesswatchersettings.ui" line="92"/>
+        <location filename="../idlenesswatchersettings.ui" line="83"/>
         <source> seconds</source>
         <translation type="unfinished"></translation>
     </message>
@@ -85,82 +106,73 @@
 <context>
     <name>LidWatcherSettings</name>
     <message>
-        <location filename="../lidwatchersettings.ui" line="14"/>
-        <source>Form</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../lidwatchersettings.ui" line="26"/>
+        <location filename="../lidwatchersettings.ui" line="23"/>
         <source>Enable &amp;Lid Watcher</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lidwatchersettings.ui" line="45"/>
+        <location filename="../lidwatchersettings.ui" line="38"/>
         <source>Action when lid is closed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lidwatchersettings.ui" line="57"/>
-        <location filename="../lidwatchersettings.ui" line="160"/>
+        <location filename="../lidwatchersettings.ui" line="50"/>
+        <location filename="../lidwatchersettings.ui" line="115"/>
         <source>On Battery</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lidwatchersettings.ui" line="77"/>
+        <location filename="../lidwatchersettings.ui" line="58"/>
         <source>Nothing</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lidwatchersettings.ui" line="82"/>
+        <location filename="../lidwatchersettings.ui" line="63"/>
         <source>Suspend</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lidwatchersettings.ui" line="87"/>
+        <location filename="../lidwatchersettings.ui" line="68"/>
         <source>Hibernate</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lidwatchersettings.ui" line="92"/>
+        <location filename="../lidwatchersettings.ui" line="73"/>
         <source>Shut down</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lidwatchersettings.ui" line="100"/>
+        <location filename="../lidwatchersettings.ui" line="81"/>
+        <location filename="../lidwatchersettings.ui" line="125"/>
         <source>On AC</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lidwatchersettings.ui" line="139"/>
+        <location filename="../lidwatchersettings.ui" line="94"/>
         <source>When &amp;using external monitor</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../lidwatchersettings.ui" line="177"/>
-        <source>On Ac</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../mainwindow.cpp" line="34"/>
-        <source>LXQt Powermanagement Configuration</source>
+        <location filename="../mainwindow.cpp" line="36"/>
+        <source>Power Management Settings</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="37"/>
+        <location filename="../mainwindow.cpp" line="39"/>
         <source>Battery</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="41"/>
+        <location filename="../mainwindow.cpp" line="43"/>
         <source>Lid</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="45"/>
-        <source>idle</source>
+        <location filename="../mainwindow.cpp" line="47"/>
+        <source>Idle</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -191,5 +203,10 @@
         <source>Shutdown</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../helpers.cpp" line="40"/>
+        <source>Turn Off monitor(s)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
