@@ -9,75 +9,96 @@
         <translation>Настройки наблюдения за батареей</translation>
     </message>
     <message>
-        <location filename="../batterywatchersettings.ui" line="37"/>
+        <location filename="../batterywatchersettings.ui" line="26"/>
         <source>E&amp;nable Battery Watcher</source>
         <translation>&amp;Разрешить наблюдение за батареей</translation>
     </message>
     <message>
-        <location filename="../batterywatchersettings.ui" line="55"/>
+        <location filename="../batterywatchersettings.ui" line="54"/>
         <source>Warning:</source>
         <translation>Предупреждение:</translation>
     </message>
     <message>
-        <location filename="../batterywatchersettings.ui" line="68"/>
+        <location filename="../batterywatchersettings.ui" line="67"/>
         <source> seconds</source>
         <translation> секунд</translation>
     </message>
     <message>
-        <location filename="../batterywatchersettings.ui" line="78"/>
+        <location filename="../batterywatchersettings.ui" line="77"/>
         <source>Level is low at:</source>
         <translation>Низкий уровень при:</translation>
     </message>
     <message>
-        <location filename="../batterywatchersettings.ui" line="91"/>
+        <location filename="../batterywatchersettings.ui" line="90"/>
         <source> %</source>
         <translation> %</translation>
     </message>
     <message>
-        <location filename="../batterywatchersettings.ui" line="98"/>
+        <location filename="../batterywatchersettings.ui" line="111"/>
         <source>Use icons from theme:</source>
         <translation>Использовать значки из темы:</translation>
     </message>
     <message>
-        <location filename="../batterywatchersettings.ui" line="112"/>
+        <location filename="../batterywatchersettings.ui" line="125"/>
+        <location filename="../batterywatchersettings.cpp" line="93"/>
+        <source>Preview</source>
+        <translation>Предварительный просмотр</translation>
+    </message>
+    <message>
+        <location filename="../batterywatchersettings.ui" line="162"/>
+        <source>Charging</source>
+        <translation>Заряжается</translation>
+    </message>
+    <message>
+        <location filename="../batterywatchersettings.ui" line="200"/>
+        <source>Discharging</source>
+        <translation>Разряжается</translation>
+    </message>
+    <message>
+        <location filename="../batterywatchersettings.ui" line="41"/>
         <source>When power is low then:</source>
         <translation>При низком заряде:</translation>
     </message>
     <message>
-        <location filename="../batterywatchersettings.ui" line="129"/>
+        <location filename="../batterywatchersettings.ui" line="97"/>
         <source>Show icon:</source>
         <translation>Показывать значок:</translation>
     </message>
+    <message>
+        <location filename="../batterywatchersettings.cpp" line="93"/>
+        <source>built in</source>
+        <translation>встроенная</translation>
+    </message>
+    <message>
+        <location filename="../batterywatchersettings.cpp" line="98"/>
+        <source>Level: %1%</source>
+        <translation>Уровень: %1%</translation>
+    </message>
 </context>
 <context>
     <name>IdlenessWatcherSettings</name>
     <message>
-        <location filename="../idlenesswatchersettings.ui" line="14"/>
-        <source>Form</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../idlenesswatchersettings.ui" line="26"/>
+        <location filename="../idlenesswatchersettings.ui" line="17"/>
         <source>Enab&amp;le Idleness Watcher</source>
-        <translation>Включить наблюдение за простоем</translation>
+        <translation>В&amp;ключить наблюдение за простоем</translation>
     </message>
     <message>
-        <location filename="../idlenesswatchersettings.ui" line="47"/>
+        <location filename="../idlenesswatchersettings.ui" line="38"/>
         <source>When idle then:</source>
         <translation>При простое:</translation>
     </message>
     <message>
-        <location filename="../idlenesswatchersettings.ui" line="66"/>
+        <location filename="../idlenesswatchersettings.ui" line="57"/>
         <source>Idle time:</source>
         <translation>Время простоя:</translation>
     </message>
     <message>
-        <location filename="../idlenesswatchersettings.ui" line="79"/>
+        <location filename="../idlenesswatchersettings.ui" line="70"/>
         <source> minutes</source>
         <translation> минут</translation>
     </message>
     <message>
-        <location filename="../idlenesswatchersettings.ui" line="92"/>
+        <location filename="../idlenesswatchersettings.ui" line="83"/>
         <source> seconds</source>
         <translation> секунд</translation>
     </message>
@@ -85,83 +106,74 @@
 <context>
     <name>LidWatcherSettings</name>
     <message>
-        <location filename="../lidwatchersettings.ui" line="14"/>
-        <source>Form</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../lidwatchersettings.ui" line="26"/>
+        <location filename="../lidwatchersettings.ui" line="23"/>
         <source>Enable &amp;Lid Watcher</source>
-        <translation>Включить наблюдение за крышкой</translation>
+        <translation>В&amp;ключить наблюдение за крышкой</translation>
     </message>
     <message>
-        <location filename="../lidwatchersettings.ui" line="45"/>
+        <location filename="../lidwatchersettings.ui" line="38"/>
         <source>Action when lid is closed</source>
         <translation>Действие при закрытии крышки</translation>
     </message>
     <message>
-        <location filename="../lidwatchersettings.ui" line="57"/>
-        <location filename="../lidwatchersettings.ui" line="160"/>
+        <location filename="../lidwatchersettings.ui" line="50"/>
+        <location filename="../lidwatchersettings.ui" line="115"/>
         <source>On Battery</source>
         <translation>От батареи</translation>
     </message>
     <message>
-        <location filename="../lidwatchersettings.ui" line="77"/>
+        <location filename="../lidwatchersettings.ui" line="58"/>
         <source>Nothing</source>
         <translation>Ничего</translation>
     </message>
     <message>
-        <location filename="../lidwatchersettings.ui" line="82"/>
+        <location filename="../lidwatchersettings.ui" line="63"/>
         <source>Suspend</source>
         <translation>Ждущий режим</translation>
     </message>
     <message>
-        <location filename="../lidwatchersettings.ui" line="87"/>
+        <location filename="../lidwatchersettings.ui" line="68"/>
         <source>Hibernate</source>
         <translation>Спящий режим</translation>
     </message>
     <message>
-        <location filename="../lidwatchersettings.ui" line="92"/>
+        <location filename="../lidwatchersettings.ui" line="73"/>
         <source>Shut down</source>
-        <translation>Выключить</translation>
+        <translation>Выключить компьютер</translation>
     </message>
     <message>
-        <location filename="../lidwatchersettings.ui" line="100"/>
+        <location filename="../lidwatchersettings.ui" line="81"/>
+        <location filename="../lidwatchersettings.ui" line="125"/>
         <source>On AC</source>
         <translation>От сети</translation>
     </message>
     <message>
-        <location filename="../lidwatchersettings.ui" line="139"/>
+        <location filename="../lidwatchersettings.ui" line="94"/>
         <source>When &amp;using external monitor</source>
-        <translation>При использовании внешнего монитора</translation>
-    </message>
-    <message>
-        <location filename="../lidwatchersettings.ui" line="177"/>
-        <source>On Ac</source>
-        <translation>От сети</translation>
+        <translation>При &amp;использовании внешнего монитора</translation>
     </message>
 </context>
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../mainwindow.cpp" line="34"/>
-        <source>LXQt Powermanagement Configuration</source>
-        <translation>Настройка энергопотребления LXQt</translation>
+        <location filename="../mainwindow.cpp" line="36"/>
+        <source>Power Management Settings</source>
+        <translation>Настройки управления энергопотреблением</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="37"/>
+        <location filename="../mainwindow.cpp" line="39"/>
         <source>Battery</source>
         <translation>Батарея</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="41"/>
+        <location filename="../mainwindow.cpp" line="43"/>
         <source>Lid</source>
         <translation>Крышка</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="45"/>
-        <source>idle</source>
-        <translation>бездействие</translation>
+        <location filename="../mainwindow.cpp" line="47"/>
+        <source>Idle</source>
+        <translation>Бездействие</translation>
     </message>
 </context>
 <context>
@@ -174,7 +186,7 @@
     <message>
         <location filename="../helpers.cpp" line="36"/>
         <source>Lock screen</source>
-        <translation>Блокирвать экран</translation>
+        <translation>Блокировать экран</translation>
     </message>
     <message>
         <location filename="../helpers.cpp" line="37"/>
@@ -191,5 +203,10 @@
         <source>Shutdown</source>
         <translation>Выключить компьютер</translation>
     </message>
+    <message>
+        <location filename="../helpers.cpp" line="40"/>
+        <source>Turn Off monitor(s)</source>
+        <translation>Выключить монитор(ы)</translation>
+    </message>
 </context>
 </TS>
