@@ -1,9 +1,10 @@
 /*
- * File:   powermanagementd.h
- * Author: Christian Surlykke
- *
- * Created on 9. februar 2014, 16:15
- */
+* Copyright (c) 2014 Christian Surlykke
+*
+* This file is part of the LXQt project. <https://lxqt.org>
+* It is distributed under the LGPL 2.1 or later license.
+* Please refer to the LICENSE file for a copy of the license.
+*/
 
 #ifndef POWERMANAGEMENTD_H
 #define	POWERMANAGEMENTD_H
@@ -36,7 +37,7 @@ private:
     IdlenessWatcher* mIdlenesswatcherd;
 
     PowerManagementSettings mSettings;
-    LxQt::Notification mNotification;
+    LXQt::Notification mNotification;
 };
 
 #endif	/* POWERMANAGEMENTD_H */
